@@ -31,7 +31,7 @@ import aws_cdk.aws_sns as sns
 my_topic = sns.Topic(self, "Topic")
 
 my_fn = lambda_.Function(self, "Fn",
-    runtime=lambda_.Runtime.NODEJS_12_X,
+    runtime=lambda_.Runtime.NODEJS_14_X,
     handler="index.handler",
     code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler")),
     # sns topic for successful invocations
@@ -49,7 +49,7 @@ import aws_cdk.aws_sqs as sqs
 dead_letter_queue = sqs.Queue(self, "DeadLetterQueue")
 
 my_fn = lambda_.Function(self, "Fn",
-    runtime=lambda_.Runtime.NODEJS_12_X,
+    runtime=lambda_.Runtime.NODEJS_14_X,
     handler="index.handler",
     code=lambda_.Code.from_inline("// your code"),
     # sqs queue for unsuccessful invocations
@@ -138,7 +138,7 @@ invocation record:
 
 
 source_fn = lambda_.Function(self, "Source",
-    runtime=lambda_.Runtime.NODEJS_12_X,
+    runtime=lambda_.Runtime.NODEJS_14_X,
     handler="index.handler",
     code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler")),
     # auto-extract on success
@@ -171,14 +171,14 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_events
-import aws_cdk.aws_lambda
-import aws_cdk.aws_sns
-import aws_cdk.aws_sqs
-import aws_cdk.core
+import aws_cdk.aws_events as _aws_cdk_aws_events_efcdfa54
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_5443dbc3
+import aws_cdk.aws_sns as _aws_cdk_aws_sns_889c7272
+import aws_cdk.aws_sqs as _aws_cdk_aws_sqs_48bffef9
+import aws_cdk.core as _aws_cdk_core_f4b25747
 
 
-@jsii.implements(aws_cdk.aws_lambda.IDestination)
+@jsii.implements(_aws_cdk_aws_lambda_5443dbc3.IDestination)
 class EventBridgeDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-lambda-destinations.EventBridgeDestination",
@@ -203,7 +203,7 @@ class EventBridgeDestination(
 
     def __init__(
         self,
-        event_bus: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
+        event_bus: typing.Optional[_aws_cdk_aws_events_efcdfa54.IEventBus] = None,
     ) -> None:
         '''
         :param event_bus: -
@@ -211,18 +211,18 @@ class EventBridgeDestination(
         :default: - use the default event bus
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EventBridgeDestination.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__7d77b070a2d9267867221ab50ebfcdfd2b21136bd87cc55766a6dbad80bfd8f1)
             check_type(argname="argument event_bus", value=event_bus, expected_type=type_hints["event_bus"])
         jsii.create(self.__class__, self, [event_bus])
 
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        _scope: aws_cdk.core.Construct,
-        fn: aws_cdk.aws_lambda.IFunction,
+        _scope: _aws_cdk_core_f4b25747.Construct,
+        fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
         *,
-        type: aws_cdk.aws_lambda.DestinationType,
-    ) -> aws_cdk.aws_lambda.DestinationConfig:
+        type: _aws_cdk_aws_lambda_5443dbc3.DestinationType,
+    ) -> _aws_cdk_aws_lambda_5443dbc3.DestinationConfig:
         '''Returns a destination configuration.
 
         :param _scope: -
@@ -230,15 +230,15 @@ class EventBridgeDestination(
         :param type: The destination type.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EventBridgeDestination.bind)
+            type_hints = typing.get_type_hints(_typecheckingstub__ea87252c682d172a9ca2c534b6db808040d39d85f88925e60955c7570adf427d)
             check_type(argname="argument _scope", value=_scope, expected_type=type_hints["_scope"])
             check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
-        _options = aws_cdk.aws_lambda.DestinationOptions(type=type)
+        _options = _aws_cdk_aws_lambda_5443dbc3.DestinationOptions(type=type)
 
-        return typing.cast(aws_cdk.aws_lambda.DestinationConfig, jsii.invoke(self, "bind", [_scope, fn, _options]))
+        return typing.cast(_aws_cdk_aws_lambda_5443dbc3.DestinationConfig, jsii.invoke(self, "bind", [_scope, fn, _options]))
 
 
-@jsii.implements(aws_cdk.aws_lambda.IDestination)
+@jsii.implements(_aws_cdk_aws_lambda_5443dbc3.IDestination)
 class LambdaDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-lambda-destinations.LambdaDestination",
@@ -254,7 +254,7 @@ class LambdaDestination(
         
         
         source_fn = lambda_.Function(self, "Source",
-            runtime=lambda_.Runtime.NODEJS_12_X,
+            runtime=lambda_.Runtime.NODEJS_14_X,
             handler="index.handler",
             code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler")),
             # auto-extract on success
@@ -266,7 +266,7 @@ class LambdaDestination(
 
     def __init__(
         self,
-        fn: aws_cdk.aws_lambda.IFunction,
+        fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
         *,
         response_only: typing.Optional[builtins.bool] = None,
     ) -> None:
@@ -275,7 +275,7 @@ class LambdaDestination(
         :param response_only: Whether the destination function receives only the ``responsePayload`` of the source function. When set to ``true`` and used as ``onSuccess`` destination, the destination function will be invoked with the payload returned by the source function. When set to ``true`` and used as ``onFailure`` destination, the destination function will be invoked with the error object returned by source function. See the README of this module to see a full explanation of this option. Default: false The destination function receives the full invocation record.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaDestination.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__24d75ef8c020ab307fe7892562f36bc2ec57c2598d7710ad53ba92243005a420)
             check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
         options = LambdaDestinationOptions(response_only=response_only)
 
@@ -284,11 +284,11 @@ class LambdaDestination(
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        scope: aws_cdk.core.Construct,
-        fn: aws_cdk.aws_lambda.IFunction,
+        scope: _aws_cdk_core_f4b25747.Construct,
+        fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
         *,
-        type: aws_cdk.aws_lambda.DestinationType,
-    ) -> aws_cdk.aws_lambda.DestinationConfig:
+        type: _aws_cdk_aws_lambda_5443dbc3.DestinationType,
+    ) -> _aws_cdk_aws_lambda_5443dbc3.DestinationConfig:
         '''Returns a destination configuration.
 
         :param scope: -
@@ -296,12 +296,12 @@ class LambdaDestination(
         :param type: The destination type.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaDestination.bind)
+            type_hints = typing.get_type_hints(_typecheckingstub__3e1cd88de5194ac2badcbd923b7a82975ed72ddf4fbac65037963c3ab3f4932a)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
-        options = aws_cdk.aws_lambda.DestinationOptions(type=type)
+        options = _aws_cdk_aws_lambda_5443dbc3.DestinationOptions(type=type)
 
-        return typing.cast(aws_cdk.aws_lambda.DestinationConfig, jsii.invoke(self, "bind", [scope, fn, options]))
+        return typing.cast(_aws_cdk_aws_lambda_5443dbc3.DestinationConfig, jsii.invoke(self, "bind", [scope, fn, options]))
 
 
 @jsii.data_type(
@@ -324,7 +324,7 @@ class LambdaDestinationOptions:
             
             
             source_fn = lambda_.Function(self, "Source",
-                runtime=lambda_.Runtime.NODEJS_12_X,
+                runtime=lambda_.Runtime.NODEJS_14_X,
                 handler="index.handler",
                 code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler")),
                 # auto-extract on success
@@ -334,9 +334,9 @@ class LambdaDestinationOptions:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaDestinationOptions.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b7fa5ad84fb9a007d11e447d85048ed485ae5153cc3b89c93416713145625788)
             check_type(argname="argument response_only", value=response_only, expected_type=type_hints["response_only"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if response_only is not None:
             self._values["response_only"] = response_only
 
@@ -369,7 +369,7 @@ class LambdaDestinationOptions:
         )
 
 
-@jsii.implements(aws_cdk.aws_lambda.IDestination)
+@jsii.implements(_aws_cdk_aws_lambda_5443dbc3.IDestination)
 class SnsDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-lambda-destinations.SnsDestination",
@@ -387,7 +387,7 @@ class SnsDestination(
         my_topic = sns.Topic(self, "Topic")
         
         my_fn = lambda_.Function(self, "Fn",
-            runtime=lambda_.Runtime.NODEJS_12_X,
+            runtime=lambda_.Runtime.NODEJS_14_X,
             handler="index.handler",
             code=lambda_.Code.from_asset(path.join(__dirname, "lambda-handler")),
             # sns topic for successful invocations
@@ -395,23 +395,23 @@ class SnsDestination(
         )
     '''
 
-    def __init__(self, topic: aws_cdk.aws_sns.ITopic) -> None:
+    def __init__(self, topic: _aws_cdk_aws_sns_889c7272.ITopic) -> None:
         '''
         :param topic: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SnsDestination.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__56c3959b4f9bd3dd154c04d6b7fae32d01160e5c877080b1f3ea76391c523394)
             check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
         jsii.create(self.__class__, self, [topic])
 
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        _scope: aws_cdk.core.Construct,
-        fn: aws_cdk.aws_lambda.IFunction,
+        _scope: _aws_cdk_core_f4b25747.Construct,
+        fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
         *,
-        type: aws_cdk.aws_lambda.DestinationType,
-    ) -> aws_cdk.aws_lambda.DestinationConfig:
+        type: _aws_cdk_aws_lambda_5443dbc3.DestinationType,
+    ) -> _aws_cdk_aws_lambda_5443dbc3.DestinationConfig:
         '''Returns a destination configuration.
 
         :param _scope: -
@@ -419,15 +419,15 @@ class SnsDestination(
         :param type: The destination type.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SnsDestination.bind)
+            type_hints = typing.get_type_hints(_typecheckingstub__b6a19fae8a77ce7bfe0f7ba8783f669cfc226b5715e83edc0a2cbc537f6c4aec)
             check_type(argname="argument _scope", value=_scope, expected_type=type_hints["_scope"])
             check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
-        _options = aws_cdk.aws_lambda.DestinationOptions(type=type)
+        _options = _aws_cdk_aws_lambda_5443dbc3.DestinationOptions(type=type)
 
-        return typing.cast(aws_cdk.aws_lambda.DestinationConfig, jsii.invoke(self, "bind", [_scope, fn, _options]))
+        return typing.cast(_aws_cdk_aws_lambda_5443dbc3.DestinationConfig, jsii.invoke(self, "bind", [_scope, fn, _options]))
 
 
-@jsii.implements(aws_cdk.aws_lambda.IDestination)
+@jsii.implements(_aws_cdk_aws_lambda_5443dbc3.IDestination)
 class SqsDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-lambda-destinations.SqsDestination",
@@ -445,7 +445,7 @@ class SqsDestination(
         dead_letter_queue = sqs.Queue(self, "DeadLetterQueue")
         
         my_fn = lambda_.Function(self, "Fn",
-            runtime=lambda_.Runtime.NODEJS_12_X,
+            runtime=lambda_.Runtime.NODEJS_14_X,
             handler="index.handler",
             code=lambda_.Code.from_inline("// your code"),
             # sqs queue for unsuccessful invocations
@@ -453,23 +453,23 @@ class SqsDestination(
         )
     '''
 
-    def __init__(self, queue: aws_cdk.aws_sqs.IQueue) -> None:
+    def __init__(self, queue: _aws_cdk_aws_sqs_48bffef9.IQueue) -> None:
         '''
         :param queue: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SqsDestination.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__3d4ac9efb142c0e85c91fce31090fb080a76ff7e3ed78e15953efb07a41bf004)
             check_type(argname="argument queue", value=queue, expected_type=type_hints["queue"])
         jsii.create(self.__class__, self, [queue])
 
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        _scope: aws_cdk.core.Construct,
-        fn: aws_cdk.aws_lambda.IFunction,
+        _scope: _aws_cdk_core_f4b25747.Construct,
+        fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
         *,
-        type: aws_cdk.aws_lambda.DestinationType,
-    ) -> aws_cdk.aws_lambda.DestinationConfig:
+        type: _aws_cdk_aws_lambda_5443dbc3.DestinationType,
+    ) -> _aws_cdk_aws_lambda_5443dbc3.DestinationConfig:
         '''Returns a destination configuration.
 
         :param _scope: -
@@ -477,12 +477,12 @@ class SqsDestination(
         :param type: The destination type.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SqsDestination.bind)
+            type_hints = typing.get_type_hints(_typecheckingstub__741e28ea5ee8d87fae0e40d8ffb319912cc80cef8f6613eb5cd7695662d0ec1f)
             check_type(argname="argument _scope", value=_scope, expected_type=type_hints["_scope"])
             check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
-        _options = aws_cdk.aws_lambda.DestinationOptions(type=type)
+        _options = _aws_cdk_aws_lambda_5443dbc3.DestinationOptions(type=type)
 
-        return typing.cast(aws_cdk.aws_lambda.DestinationConfig, jsii.invoke(self, "bind", [_scope, fn, _options]))
+        return typing.cast(_aws_cdk_aws_lambda_5443dbc3.DestinationConfig, jsii.invoke(self, "bind", [_scope, fn, _options]))
 
 
 __all__ = [
@@ -494,3 +494,72 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__7d77b070a2d9267867221ab50ebfcdfd2b21136bd87cc55766a6dbad80bfd8f1(
+    event_bus: typing.Optional[_aws_cdk_aws_events_efcdfa54.IEventBus] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ea87252c682d172a9ca2c534b6db808040d39d85f88925e60955c7570adf427d(
+    _scope: _aws_cdk_core_f4b25747.Construct,
+    fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
+    *,
+    type: _aws_cdk_aws_lambda_5443dbc3.DestinationType,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__24d75ef8c020ab307fe7892562f36bc2ec57c2598d7710ad53ba92243005a420(
+    fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
+    *,
+    response_only: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3e1cd88de5194ac2badcbd923b7a82975ed72ddf4fbac65037963c3ab3f4932a(
+    scope: _aws_cdk_core_f4b25747.Construct,
+    fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
+    *,
+    type: _aws_cdk_aws_lambda_5443dbc3.DestinationType,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b7fa5ad84fb9a007d11e447d85048ed485ae5153cc3b89c93416713145625788(
+    *,
+    response_only: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__56c3959b4f9bd3dd154c04d6b7fae32d01160e5c877080b1f3ea76391c523394(
+    topic: _aws_cdk_aws_sns_889c7272.ITopic,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b6a19fae8a77ce7bfe0f7ba8783f669cfc226b5715e83edc0a2cbc537f6c4aec(
+    _scope: _aws_cdk_core_f4b25747.Construct,
+    fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
+    *,
+    type: _aws_cdk_aws_lambda_5443dbc3.DestinationType,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3d4ac9efb142c0e85c91fce31090fb080a76ff7e3ed78e15953efb07a41bf004(
+    queue: _aws_cdk_aws_sqs_48bffef9.IQueue,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__741e28ea5ee8d87fae0e40d8ffb319912cc80cef8f6613eb5cd7695662d0ec1f(
+    _scope: _aws_cdk_core_f4b25747.Construct,
+    fn: _aws_cdk_aws_lambda_5443dbc3.IFunction,
+    *,
+    type: _aws_cdk_aws_lambda_5443dbc3.DestinationType,
+) -> None:
+    """Type checking stubs"""
+    pass
